def add(*a):
	sum = 0
	for i in a:
		sum = sum+i
	print("the addition of given numbers is-->",sum)


def mul(*a):
	ml = 1
	for i in a:
		ml = ml*i
	print("the multiplication of given numbers is-->",ml)

